@@ -104,9 +104,9 @@ static void beginning_of_buffer(void)
 
 static void end_of_buffer(void)
 {
-  int s = getfilesize();
+  INT s = getfilesize();
   cursorOffset = 0;
-  if (option == bySector) set_base(floor(s, page));
+  if (option == bySector) set_base(myfloor(s, page));
   set_cursor(s);
 }
 
@@ -253,13 +253,14 @@ void ask_about_save_and_quit(void)
 
 static void goto_char(void)
 {
-  int i, b;
+  long long i;
+  int b;
   char tmp[BLOCK_SEARCH_SIZE];
 
   echo();
   displayOneLineMessage("New position ? 0x");
   getstr(tmp);
-  b = sscanf(tmp, "%lx",&i);
+  b = sscanf(tmp, "%llx",&i);
   noecho();
   if (b != 1 || !set_cursor(i)) displayMessageAndWaitForKey("Invalid position!");
 }
@@ -287,7 +288,7 @@ static void save_buffer(void)
   int displayedmessage = FALSE;
   typePage *p, *q;
   for (p = edited; p; p = q) {
-    if (lseek(fd, p->base, SEEK_SET) == -1 || write(fd, p->vals, p->size) == -1)
+    if (LSEEK_(fd, p->base) == -1 || write(fd, p->vals, p->size) == -1)
       if (!displayedmessage) {  /* It would be annoying to display lots of error messages when we can't write. */
 	displayMessageAndWaitForKey(strerror(errno));
 	displayedmessage = TRUE;
