@@ -33,8 +33,8 @@ static int searchA(char **string, int *sizea, char *tmp)
   *sizea = strlen(tmp);
   if (hexOrAscii) if (!hexStringToBinString(tmp, sizea)) return FALSE;
 
-  *string = strdup(tmp);
-  *sizea = strlen(*string);
+  *string = malloc(*sizea);
+  memcpy(*string, tmp, *sizea);
 
   nodelay(stdscr, TRUE);
   displayTwoLineMessage("searching...", "(press any key to cancel)");
@@ -56,19 +56,19 @@ void search_forward(void)
 {
   char *p, *string, tmp[BLOCK_SEARCH_SIZE], tmpstr[BLOCK_SEARCH_SIZE];
   int quit, sizea, sizeb;
-  int blockstart;
+  INT blockstart;
 
   if (!searchA(&string, &sizea, tmp)) return;
   quit = -1;
   blockstart = base + cursor - BLOCK_SEARCH_SIZE + sizea;
   do {
     blockstart += BLOCK_SEARCH_SIZE - sizea + 1;
-    lseek(fd, blockstart, SEEK_SET);
+    LSEEK(fd, blockstart);
     if ((sizeb = read(fd, tmp, BLOCK_SEARCH_SIZE)) < sizea) quit = -3;
     else if (getch() != ERR) quit = -2;
     else if ((p = mymemmem(tmp, sizeb, string, sizea))) quit = p - tmp;
 
-    sprintf(tmpstr,"searching... 0x%08lX", blockstart);
+    sprintf(tmpstr,"searching... 0x%08llX", (long long) blockstart);
     nodelay(stdscr, TRUE);
     displayTwoLineMessage(tmpstr, "(press any key to cancel)");
 
@@ -81,7 +81,7 @@ void search_backward(void)
 {
   char *p, *string, tmp[BLOCK_SEARCH_SIZE], tmpstr[BLOCK_SEARCH_SIZE];
   int quit, sizea, sizeb;
-  int blockstart;
+  INT blockstart;
 
   if (!searchA(&string, &sizea, tmp)) return;
   quit = -1;
@@ -93,13 +93,13 @@ void search_backward(void)
 
     if (sizeb < sizea) quit = -3;
     else {
-      lseek(fd, blockstart, SEEK_SET);
+      LSEEK(fd, blockstart);
       if (sizeb != read(fd, tmp, sizeb)) quit = -3;
       else if (getch() != ERR) quit = -2;
       else if ((p = mymemrmem(tmp, sizeb, string, sizea))) quit = p - tmp;
     }
 
-    sprintf(tmpstr,"searching... 0x%08lX", blockstart);
+    sprintf(tmpstr,"searching... 0x%08llX", (long long) blockstart);
     nodelay(stdscr, TRUE);
     displayTwoLineMessage(tmpstr, "(press any key to cancel)");
 
